@@ -1,24 +1,11 @@
-/***************************************************************************
- *   Copyright 2001 Bernd Gehrmann <bernd@kdevelop.org>                    *
- *   Copyright 2004-2005 Sascha Cunz <sascha@kdevelop.org>                 *
- *   Copyright 2007 Alexander Dymo <adymo@kdevelop.org>                    *
- *   Copyright 2008 Anne-Marie Mahfouf <annma@kde.org>                     *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA .        *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2001 Bernd Gehrmann <bernd@kdevelop.org>
+    SPDX-FileCopyrightText: 2004-2005 Sascha Cunz <sascha@kdevelop.org>
+    SPDX-FileCopyrightText: 2007 Alexander Dymo <adymo@kdevelop.org>
+    SPDX-FileCopyrightText: 2008 Anne-Marie Mahfouf <annma@kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <KLocalizedString>
 
@@ -148,7 +135,7 @@ QPixmap generateTemplatePreviewPicture(const QString& iconName, const QString& a
 void ChoicePage::itemSelected(const QModelIndex &index)
 {
     if (!index.isValid()){
-        emit completeChanged();
+        Q_EMIT completeChanged();
         return;
     }
 
@@ -179,8 +166,8 @@ void ChoicePage::itemSelected(const QModelIndex &index)
         ui_choice.kcfg_appName->setFocus(Qt::MouseFocusReason);
     }
 
-    emit templateNameChanged(m_baseName);
-    emit completeChanged();
+    Q_EMIT templateNameChanged(m_baseName);
+    Q_EMIT completeChanged();
 }
 
 void ChoicePage::loadFromFile()
